==> telepathy-mission-control_4.37.orig.tar.gz: telepathy-mission-control-4.37/libmissioncontrol/mission-control-signals-marshal.h <==

#ifndef __mission_control_signals_marshal_MARSHAL_H__
#define __mission_control_signals_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:UINT,UINT,UINT,STRING (mission-control-signals-marshal.list:1) */
extern void mission_control_signals_marshal_VOID__UINT_UINT_UINT_STRING (GClosure     *closure,
                                                                         GValue       *return_value,
                                                                         guint         n_param_values,
                                                                         const GValue *param_values,
                                                                         gpointer      invocation_hint,
                                                                         gpointer      marshal_data);

/* VOID:STRING,UINT (mission-control-signals-marshal.list:2) */
extern void mission_control_signals_marshal_VOID__STRING_UINT (GClosure     *closure,
                                                               GValue       *return_value,
                                                               guint         n_param_values,
                                                               const GValue *param_values,
                                                               gpointer      invocation_hint,
                                                               gpointer      marshal_data);

/* VOID:UINT,UINT (mission-control-signals-marshal.list:3) */
extern void mission_control_signals_marshal_VOID__UINT_UINT (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
                                                             const GValue *param_values,
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);

/* VOID:UINT,STRING,UINT (mission-control-signals-marshal.list:4) */
extern void mission_control_signals_marshal_VOID__UINT_STRING_UINT (GClosure     *closure,
                                                                    GValue       *return_value,
                                                                    guint         n_param_values,
                                                                    const GValue *param_values,
                                                                    gpointer      invocation_hint,
                                                                    gpointer      marshal_data);

/* VOID:UINT (mission-control-signals-marshal.list:5) */
#define mission_control_signals_marshal_VOID__UINT	g_cclosure_marshal_VOID__UINT

G_END_DECLS

#endif /* __mission_control_signals_marshal_MARSHAL_H__ */

==> telepathy-mission-control_4.65.orig.tar.gz: telepathy-mission-control-4.65/libmissioncontrol/mission-control-signals-marshal.h <==

#ifndef __mission_control_signals_marshal_MARSHAL_H__
#define __mission_control_signals_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:UINT,UINT,UINT,STRING (mission-control-signals-marshal.list:1) */
extern void mission_control_signals_marshal_VOID__UINT_UINT_UINT_STRING (GClosure     *closure,
                                                                         GValue       *return_value,
                                                                         guint         n_param_values,
                                                                         const GValue *param_values,
                                                                         gpointer      invocation_hint,
                                                                         gpointer      marshal_data);

/* VOID:STRING,UINT (mission-control-signals-marshal.list:2) */
extern void mission_control_signals_marshal_VOID__STRING_UINT (GClosure     *closure,
                                                               GValue       *return_value,
                                                               guint         n_param_values,
                                                               const GValue *param_values,
                                                               gpointer      invocation_hint,
                                                               gpointer      marshal_data);

/* VOID:UINT,UINT (mission-control-signals-marshal.list:3) */
extern void mission_control_signals_marshal_VOID__UINT_UINT (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
                                                             const GValue *param_values,
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);

/* VOID:UINT,STRING,UINT (mission-control-signals-marshal.list:4) */
extern void mission_control_signals_marshal_VOID__UINT_STRING_UINT (GClosure     *closure,
                                                                    GValue       *return_value,
                                                                    guint         n_param_values,
                                                                    const GValue *param_values,
                                                                    gpointer      invocation_hint,
                                                                    gpointer      marshal_data);

/* VOID:UINT (mission-control-signals-marshal.list:5) */
#define mission_control_signals_marshal_VOID__UINT	g_cclosure_marshal_VOID__UINT

/* VOID:UINT,UINT,STRING,UINT,STRING (mission-control-signals-marshal.list:6) */
extern void mission_control_signals_marshal_VOID__UINT_UINT_STRING_UINT_STRING (GClosure     *closure,
                                                                                GValue       *return_value,
                                                                                guint         n_param_values,
                                                                                const GValue *param_values,
                                                                                gpointer      invocation_hint,
                                                                                gpointer      marshal_data);

/* VOID:UINT,STRING (mission-control-signals-marshal.list:7) */
extern void mission_control_signals_marshal_VOID__UINT_STRING (GClosure     *closure,
                                                               GValue       *return_value,
                                                               guint         n_param_values,
                                                               const GValue *param_values,
                                                               gpointer      invocation_hint,
                                                               gpointer      marshal_data);

G_END_DECLS

#endif /* __mission_control_signals_marshal_MARSHAL_H__ */
